@@ -1282,7 +1282,10 @@ login_tty(t)
 #endif
 			fatalperror(net, "setsid()");
 	}
-# ifdef	TIOCSCTTY
+/* 
+  TIOCSCTTY does not work on HP-UX, thm
+*/
+# if  defined(TIOCSCTTY) && !defined(__hpux)
 	if (ioctl(t, TIOCSCTTY, (char *)0) < 0)
 		fatalperror(net, "ioctl(sctty)");
 #  if defined(CRAY)
@@ -1302,7 +1305,9 @@ login_tty(t)
 	 * setsid() call above may have set our pgrp, so clear
 	 * it out before opening the tty...
 	 */
+#  ifndef __hpux   /* thm */
 	(void) setpgrp(0, 0);
+#  endif
 	close(open(line, O_RDWR));
 # endif
 	if (t != 0)
